==> phpMyGPX-0.5.tar.bz2: phpmygpx/waypoints.php <==
<?php
/**
* @version $Id: $
* @package osm-things
* @copyright Copyright (C) 2008 Sebastian Klemm.
* @license http://www.gnu.org/copyleft/gpl.html GNU/GPL, see LICENSE.php
*/

define( '_VALID_OSM', TRUE );
define( '_PATH', './' );
$DEBUG = FALSE;
if($DEBUG) error_reporting(E_ALL);

session_start();

include("./config.inc.php");
include("./libraries/functions.inc.php");
include("./libraries/classes.php");
include("./libraries/html.classes.php");
include("./libraries/GeoCalc.class.php");
include("./waypoints.html.php");

setlocale (LC_TIME, $cfg['config_locale']);
include("./languages/".get_lang($cfg['config_language']).".php");
include("./head.html.php");

if($cfg['show_exec_time'])
    $startTime = microtime_float();

if($DEBUG) {
    foreach($_POST as $akey => $val)
        out("<b>$akey</b> = $val", "OUT_DEBUG");
}

$p = intval($_GET['p']);
$id = intval($_GET['id']);
$task = strip_tags($_GET['task']);
$option = strip_tags($_GET['option']);
$f_date = strip_tags($_GET['date']);
$f_lat = floatval($_GET['lat']);
$f_lon = floatval($_GET['lon']);
$f_lat_range = floatval($_GET['lat_range']);
$f_lon_range = floatval($_GET['lon_range']);
$name = strip_tags($_GET['name']);
$comment = strip_tags($_GET['cmt']);
$description = strip_tags($_GET['desc']);
$submit = strip_tags($_POST['submit']);
$confirm = strip_tags($_POST['confirm']);

// convert lat/lon from float value to database integer format
if($option == "search") {
	$option = "filter";
	$f_lat *= 1000000; 
	$f_lon *= 1000000; 
	$f_lat_range *= 1000000; 
	$f_lon_range *= 1000000; 
}

// connect to database
$link = db_connect_h($cfg['db_host'], $cfg['db_name'], $cfg['db_user'], $cfg['db_password']);

if(!$cfg['embedded_mode']) {
	HTML::heading(_APP_NAME, 2);
	HTML::main_menu();
}

switch ($task) {
	case 'view':
		viewWaypoints($id, $p);
		break;

	case 'export':
		exportWaypoints($id);
		break;

	case 'download':
		downloadWaypoints($id);
		break;

	case 'delete':
		deleteWaypoints($id, $confirm);
		break;

	case 'search':
		searchWaypoints();
		break;

	default:
        viewWaypoints(NULL, NULL);
		break;
}


function viewWaypoints($id, $page) {
	global $DEBUG, $cfg;
	global $option, $f_date, $f_lat, $f_lon, $f_lat_range, $f_lon_range;
	global $name, $comment, $description;
	HTML::heading(_MENU_WPT_VIEW, 3);
	$search_url = "";
	$limit = $cfg['result_table_limit'];
	$query = "SELECT SQL_CALC_FOUND_ROWS * FROM `${cfg['db_table_prefix']}waypoints` ";
	if($id)
		$query .= "WHERE `gpx_id` = '$id' ";
	if($option == "filter") {
		$query .= "WHERE 1 ";
		if($f_date)
			$query .= "AND DATE(`timestamp`) = '$f_date' ";
		if($f_lat)
			$query .= "AND `latitude` BETWEEN '$f_lat'-'$f_lat_range' 
					AND '$f_lat'+'$f_lat_range' ";
		if($f_lon)
			$query .= "AND `longitude` BETWEEN '$f_lon'-'$f_lon_range' 
					AND '$f_lon'+'$f_lon_range' ";
		if($name)
			$query .= "AND `name` LIKE '%".db_escape_string($name)."%' ";
		if($comment)
			$query .= "AND `cmt` LIKE '%".db_escape_string($comment)."%' ";
		if($description)
			$query .= "AND `desc` LIKE '%".db_escape_string($description)."%' ";

		$search_url = "&option=filter&date=$f_date&lat=$f_lat&lon=$f_lon&lat_range=$f_lat_range&lon_range=$f_lon_range&name=$name&cmt=$comment&desc=$description";
	}
	$query .= "ORDER BY `timestamp` LIMIT ". ($page*$limit) .", $limit ;";
    $result = db_query($query);
	if($DEBUG)	out($query, 'OUT_DEBUG');
    if(mysql_num_rows($result)) {
		$num_found = mysql_result(db_query("SELECT FOUND_ROWS();") ,0);
		HTML::viewPagination($page, ceil($num_found/$limit), 
			"waypoints.php?task=view&id=$id".$search_url);
		HTML_waypoints::viewWPTsTableHeader();
		while($row = mysql_fetch_array($result, MYSQL_ASSOC)) {
			HTML_waypoints::viewWPTsTableRow($row);
		}
		HTML_waypoints::viewWPTsTableFooter();
		HTML::viewPagination($page, ceil($num_found/$limit), 
			"waypoints.php?task=view&id=$id".$search_url);
		HTML::message($num_found ._DB_WPTS_AVAILABLE);
		if($option == "filter") {
			HTML::message("<a href='export.php?type=waypoints$search_url'>". _TRC_EXPORT_AS_GPX ."</a>");
		}
	}
	else
		HTML::message(_TRC_NO_WPTS_IN_DB);
}

function exportWaypoints($id) {
	global $DEBUG, $cfg, $option;
    HTML::heading(_MENU_WPT_EXPORT, 3);
    HTML::message(_CMN_NOT_IMPLEMENTED);
}

function downloadWaypoints($id) {
	global $DEBUG, $cfg;
    HTML::heading(_MENU_WPT_DOWNL, 3);
    HTML::message(_CMN_NOT_IMPLEMENTED);
}

function deleteWaypoints($id, $confirm) {
	global $DEBUG, $cfg;
	global $submit;
    HTML::heading(_MENU_WPT_DELETE, 3);
    if(!$cfg['public_host'] || check_password($cfg['admin_password'])) {
	    if(!$submit) {
	    	HTML_waypoints::deleteForm('waypoints.php?task=delete&id='.$id, $id);
	    } else {
			if($confirm == _CMN_YES) {
				// delete waypoints
		        $query = "DELETE IGNORE FROM `${cfg['db_table_prefix']}waypoints` 
		        	WHERE `gpx_id` = '$id' ;";
		        $result = db_query($query);
		        $num_rows = mysql_affected_rows();
		        HTML::message_r(_TRC_WPT_DELETED, $num_rows);
			} else {
				HTML::message(_TRC_NO_CONFIRM_DELETE);
			}    
	    }
    }else {
    	HTML::message(_NOT_AUTH ." ". _DO_LOGIN);
    }
}

function searchWaypoints() {
	global $DEBUG, $cfg;
    HTML::heading(_MENU_WPT_SEARCH, 3);
    HTML_waypoints::searchWptForm('');
}


if($cfg['show_exec_time']) {
    $endTime = microtime_float();
    $exectime = round($endTime - $startTime, 4);
}
include("./foot.html.php");
?>

==> phpMyGPX-0.5.1.tar.bz2: phpmygpx/waypoints.php <==
<?php
/**
* @version $Id: $
* @package osm-things
* @copyright Copyright (C) 2008 Sebastian Klemm.
* @license http://www.gnu.org/copyleft/gpl.html GNU/GPL, see LICENSE.php
*/

define( '_VALID_OSM', TRUE );
define( '_PATH', './' );
$DEBUG = FALSE;
if($DEBUG) error_reporting(E_ALL);

session_start();
ob_start();

include("./config.inc.php");
include("./libraries/functions.inc.php");
include("./libraries/classes.php");
include("./libraries/html.classes.php");
include("./libraries/GeoCalc.class.php");
include("./waypoints.html.php");

setlocale (LC_TIME, $cfg['config_locale']);
include("./languages/".get_lang($cfg['config_language']).".php");
include("./head.html.php");

if($cfg['show_exec_time'])
    $startTime = microtime_float();

if($DEBUG) {
    foreach($_POST as $akey => $val)
        out("<b>$akey</b> = $val", "OUT_DEBUG");
}

$limit 			= getUrlParam('HTTP_GET', 'INT', 'l');
$p 				= getUrlParam('HTTP_GET', 'INT', 'p');
$id 			= getUrlParam('HTTP_GET', 'INT', 'id');
$task 			= getUrlParam('HTTP_GET', 'STRING', 'task');
$option 		= getUrlParam('HTTP_GET', 'STRING', 'option');
$f_date 		= getUrlParam('HTTP_GET', 'STRING', 'date');
$f_lat			= getUrlParam('HTTP_GET', 'FLOAT', 'lat');
$f_lon			= getUrlParam('HTTP_GET', 'FLOAT', 'lon');
$f_lat_range 	= getUrlParam('HTTP_GET', 'FLOAT', 'lat_range');
$f_lon_range 	= getUrlParam('HTTP_GET', 'FLOAT', 'lon_range');
$name 			= getUrlParam('HTTP_GET', 'STRING', 'name');
$comment 		= getUrlParam('HTTP_GET', 'STRING', 'cmt');
$description 	= getUrlParam('HTTP_GET', 'STRING', 'desc');
$submit			= getUrlParam('HTTP_POST', 'STRING', 'submit');
$confirm		= getUrlParam('HTTP_POST', 'STRING', 'confirm');

// convert lat/lon from float value to database integer format
if($option == "search") {
	$option = "filter";
	$f_lat *= 1000000; 
	$f_lon *= 1000000; 
	$f_lat_range *= 1000000; 
	$f_lon_range *= 1000000; 
}

// handling of sql result limit
if($limit) {
	// calc new page number caused by changed result limit
	$p = round($p * $_COOKIE['limit'] / $limit);
	setcookie('limit', $limit, time() + 3600 * $cfg['pref_cookie_lifetime']);
} elseif(isset($_COOKIE['limit']))
	$limit = $_COOKIE['limit'];
// use default from config file if not set in cookie
if(!$limit)
	$limit = $cfg['result_table_limit'];

// connect to database
$link = db_connect_h($cfg['db_host'], $cfg['db_name'], $cfg['db_user'], $cfg['db_password']);

if(!$cfg['embedded_mode'] || !$cfg['public_host'] || check_password($cfg['admin_password'])) {
	HTML::heading(_APP_NAME, 2);
	HTML::main_menu();
}

switch ($task) {
	case 'view':
		viewWaypoints($id, $p, $limit);
		break;

	case 'export':
		exportWaypoints($id);
		break;

	case 'download':
		downloadWaypoints($id);
		break;

	case 'delete':
		deleteWaypoints($id, $confirm);
		break;

	case 'search':
		searchWaypoints();
		break;

	default:
        viewWaypoints(NULL, NULL);
		break;
}


function viewWaypoints($id, $page, $limit) {
	global $DEBUG, $cfg;
	global $option, $f_date, $f_lat, $f_lon, $f_lat_range, $f_lon_range;
	global $name, $comment, $description;
	HTML::heading(_MENU_WPT_VIEW, 3);
	$search_url = "";
	
	$query = "SELECT SQL_CALC_FOUND_ROWS * FROM `${cfg['db_table_prefix']}waypoints` ";
	if($id)
		$query .= "WHERE `gpx_id` = '$id' ";
	if($option == "filter") {
		$query .= "WHERE 1 ";
		if($f_date)
			$query .= "AND DATE(`timestamp`) = '$f_date' ";
		if($f_lat)
			$query .= "AND `latitude` BETWEEN '$f_lat'-'$f_lat_range' 
					AND '$f_lat'+'$f_lat_range' ";
		if($f_lon)
			$query .= "AND `longitude` BETWEEN '$f_lon'-'$f_lon_range' 
					AND '$f_lon'+'$f_lon_range' ";
		if($name)
			$query .= "AND `name` LIKE '%".db_escape_string($name)."%' ";
		if($comment)
			$query .= "AND `cmt` LIKE '%".db_escape_string($comment)."%' ";
		if($description)
			$query .= "AND `desc` LIKE '%".db_escape_string($description)."%' ";

		$search_url = "&option=filter&date=$f_date&lat=$f_lat&lon=$f_lon&lat_range=$f_lat_range&lon_range=$f_lon_range&name=$name&cmt=$comment&desc=$description";
	}
	$query .= "ORDER BY `timestamp` LIMIT ". ($page*$limit) .", $limit ;";
    $result = db_query($query);
	if($DEBUG)	out($query, 'OUT_DEBUG');
    if(mysql_num_rows($result)) {
		$num_found = mysql_result(db_query("SELECT FOUND_ROWS();") ,0);
		HTML::viewPagination($page, ceil($num_found/$limit), 
			"waypoints.php?task=view&id=$id".$search_url);
		HTML::viewResultLimitSelect("waypoints.php?task=view&id=$id&p=$page".$search_url);
		
		HTML_waypoints::viewWPTsTableHeader();
		while($row = mysql_fetch_array($result, MYSQL_ASSOC)) {
			HTML_waypoints::viewWPTsTableRow($row);
		}
		HTML_waypoints::viewWPTsTableFooter();
		
		HTML::viewPagination($page, ceil($num_found/$limit), 
			"waypoints.php?task=view&id=$id".$search_url);
		HTML::message($num_found ._DB_WPTS_AVAILABLE);
		if($option == "filter") {
			HTML::message("<a href='export.php?type=waypoints$search_url'>". _TRC_EXPORT_AS_GPX ."</a>");
		}
	}
	else
		HTML::message(_TRC_NO_WPTS_IN_DB);
}

function exportWaypoints($id) {
	global $DEBUG, $cfg, $option;
    HTML::heading(_MENU_WPT_EXPORT, 3);
    HTML::message(_CMN_NOT_IMPLEMENTED);
}

function downloadWaypoints($id) {
	global $DEBUG, $cfg;
    HTML::heading(_MENU_WPT_DOWNL, 3);
    HTML::message(_CMN_NOT_IMPLEMENTED);
}

function deleteWaypoints($id, $confirm) {
	global $DEBUG, $cfg;
	global $submit;
    HTML::heading(_MENU_WPT_DELETE, 3);
    if(!$cfg['public_host'] || check_password($cfg['admin_password'])) {
	    if(!$submit) {
	    	HTML_waypoints::deleteForm('waypoints.php?task=delete&id='.$id, $id);
	    } else {
			if($confirm == _CMN_YES) {
				// delete waypoints
		        $query = "DELETE IGNORE FROM `${cfg['db_table_prefix']}waypoints` 
		        	WHERE `gpx_id` = '$id' ;";
		        $result = db_query($query);
		        $num_rows = mysql_affected_rows();
		        HTML::message_r(_TRC_WPT_DELETED, $num_rows);
			} else {
				HTML::message(_TRC_NO_CONFIRM_DELETE);
			}    
	    }
    }else {
    	HTML::message(_NOT_AUTH ." ". _DO_LOGIN);
    }
}

function searchWaypoints() {
	global $DEBUG, $cfg;
    HTML::heading(_MENU_WPT_SEARCH, 3);
    HTML_waypoints::searchWptForm('');
}


if($cfg['show_exec_time']) {
    $endTime = microtime_float();
    $exectime = round($endTime - $startTime, 4);
}
include("./foot.html.php");
?>
